from ShynaProcess import Shprocess
import os
from ShynaDatabase import Shdatabase


class ShynaStartTest:
    s_process = Shprocess.ShynaSpeak()
    s_data = Shdatabase.ShynaDatabase()
    s_data.device_id = "termux"

    def test_tts(self):
        msg = "hello" + str(os.environ.get("bossname"))
        self.s_process.shyna_speaks(msg=msg)
        self.s_data.set_date_system(process_name="termux_test")


if __name__ == '__main__':
    ShynaStartTest().test_tts()



from Shynatime import ShTime
from ShynaDatabase import Shdatabase
import os


class ShynaLocation:
    result = ""
    s_time = ShTime.ClassTime()
    s_data = Shdatabase.ShynaDatabase()
    s_data.device_id = "termux"

    def get_location(self):
        self.result = "Empty location"
        try:
            my_cmd = os.popen('termux-location -p network').read()
            if str(my_cmd) != '':
                new_dict = eval(my_cmd)
                new_latitude = new_dict['latitude']
                new_longitude = new_dict['longitude']
                new_altitude = new_dict['altitude']
                new_accuracy = new_dict['accuracy']
                new_vertical_accuracy = new_dict['vertical_accuracy']
                new_bearing = new_dict['bearing']
                new_speed = new_dict['speed']
                new_elapsedMS = new_dict['elapsedMs']
                new_provider = new_dict['provider']
                new_date = str(self.s_time.now_date)
                new_time = str(self.s_time.now_time)
                self.s_data.query = "INSERT INTO shivam_device_location(new_date, new_time, new_latitude, " \
                                    "new_longitude, new_altitude, new_accuracy, new_vertical_accuracy, new_bearing, " \
                                    "new_speed, new_elapsedMS, new_provider) VALUES ('" + str(new_date) + "','" \
                                    + str(new_time) + "', '" + str(new_latitude) + "', '" + str(new_longitude) + "', '" \
                                    + str(new_altitude) + "', '" + str(new_accuracy) + "', '" \
                                    + str(new_vertical_accuracy) + "', '" + str(new_bearing) + "', '" \
                                    + str(new_speed) + "', '" + str(new_elapsedMS) + "','" + str(new_provider) + "')"
                self.s_data.create_insert_update_or_delete()
                self.result = "Got Location"
            else:
                self.result = "Empty location"
        except Exception as e:
            print(e)
            self.result = "Exception"
        finally:
            self.s_data.set_date_system(process_name='location_check')
            return self.result


if __name__ == '__main__':
    ShynaLocation().get_location()



import os
from ShynaProcess import Shprocess


class ShynaCharge:
    s_process = Shprocess.ShynaSpeak()

    def check_charge(self):
        try:
            dic_charge = os.popen('termux-battery-status').read()
            dic_charge = eval(dic_charge)
            charge = dic_charge['percentage']
            status = dic_charge['status']
            if int(charge) < 15 and str(status).lower() == 'discharging':
                self.s_process.shyna_speaks(msg="Hey! Shiv please plugin the charger. My battery is low")
            elif int(charge) > 95 and str(status).lower() == 'full':
                self.s_process.shyna_speaks(msg="Hey! Shiv please unplug the charger. My battery is full")
            else:
                print("All good")
        except Exception as e:
            print(e)


if __name__ == '__main__':
    ShynaCharge().check_charge()



import os
from Shynatime import ShTime
from ShynaDatabase import Shdatabase
from ShynaProcess import Shprocess
import re
import multiprocessing


# Todo: Can put the regex code in process package


class ShynaMakeAlarm:
    s_time = ShTime.ClassTime()
    s_data = Shdatabase.ShynaDatabase()
    s_process = Shprocess.ShynaSpeak()
    reminder_date = s_time.now_date
    reminder_time = s_time.now_time
    response = None

    def make_alarm(self, call):
        try:
            regex = r"(wake me up at)"
            matches = re.finditer(regex, call.lower(), re.MULTILINE)
            for matchNum, match in enumerate(matches, start=1):
                matches = match.group()
                if len(str(matches)) > 0:
                    call = self.s_time.check_am_pm(text_string=call)
                    status, self.reminder_date, self.reminder_time = self.s_time.get_date_and_time_for_alarm(text_string=call)
                    print("setting Alarm for", self.reminder_date, self.reminder_time)
                else:
                    pass
            regex = r"(let me know when it is)"
            matches = re.finditer(regex, call.lower(), re.MULTILINE)
            for matchNum, match in enumerate(matches, start=1):
                matches = match.group()
                if len(str(matches)) > 0:
                    call = self.s_time.check_am_pm(text_string=call)
                    status, self.reminder_date, self.reminder_time = self.s_time.get_date_and_time_for_alarm(text_string=call)
                    print("setting Alarm for", self.reminder_date, self.reminder_time)
                else:
                    pass
            regex = r"(alarm)"
            matches = re.finditer(regex, call.lower(), re.MULTILINE)
            for matchNum, match in enumerate(matches, start=1):
                matches = match.group()
                if len(str(matches)) > 0:
                    call = self.s_time.check_am_pm(text_string=call)
                    status, self.reminder_date, self.reminder_time = self.s_time.get_date_and_time_for_alarm(text_string=call)
                else:
                    pass
            alarm_title = "Setting up Alarm for " + self.reminder_date + " " + self.reminder_time
            command = "termux-toast -g top " + alarm_title
            os.popen(cmd=command)
            if call.lower().__contains__('let me know'):
                status = "no"
            else:
                multiprocessing.Process(target=self.s_process.shyna_speaks_termux(msg="Want to setup repeat?")).start()
                status = str(self.run_cmd_with_response(command="termux-dialog speech")['text']).lower()
            if status.__contains__('no'):
                self.s_data.query = "INSERT INTO alarm (task_date, task_time, alarm_title, alarm_date, alarm_time, " \
                                    "snooze_status, snooze_duration, repeat_status ,repeat_frequency, alarm_status) " \
                                    "VALUES ('" + str(self.s_time.now_date) + "', '" \
                                    + str(self.s_time.now_time) + "', '" + str(alarm_title) + "', '" \
                                    + str(self.reminder_date) + "', '" + str(self.reminder_time) + "', 'TRUE', " \
                                                                                                   "'15', 'False', " \
                                                                                                   "'Never', 'TRUE')"
                multiprocessing.Process(target=self.s_data.create_insert_update_or_delete()).start()
                multiprocessing.Process(target=self.s_process.shyna_speaks_termux(msg="consider it done"))
            else:
                command = "termux-dialog spinner -t 'select duration' -v 'Daily, Weekends, Weekdays, Alternative, Never'"
                snooze = str(self.run_cmd_with_response(command=command)['text']).lower()
                self.s_data.query = "INSERT INTO alarm (task_date, task_time, alarm_title, alarm_date, alarm_time, " \
                                    "snooze_status, snooze_duration, repeat_frequency, alarm_status) VALUES ('" \
                                    + str(self.s_time.now_date) + "', '" + str(self.s_time.now_time) + "', '" \
                                    + str(alarm_title) + "', '" + str(self.reminder_date) + "', '" \
                                    + str(self.reminder_time) + "', 'TRUE', '15', '" + str(snooze) + "', 'TRUE')"
                multiprocessing.Process(target=self.s_data.create_insert_update_or_delete()).start()
                multiprocessing.Process(target=self.s_process.shyna_speaks_termux(msg="consider it done"))
        except Exception as e:
            self.s_process.shyna_speaks_termux(msg="Ops! this is broken")
            print(e)

    def run_cmd_with_response(self, command, priority=None):
        try:
            if priority is None:
                priority = 1
            if priority == 1:
                self.response = os.popen(str(command)).read()
                self.response = eval(self.response)
            else:
                self.s_process.updated_speak_or_not_status(status=True)
                self.response = os.popen(str(command)).read()
                self.response = eval(self.response)
        except Exception as e:
            print(e)
            self.response = str(e)
        finally:
            return self.response

    def initiate_interaction(self):
        try:
            morning_list = ['good morning', 'morning', 'i am up', 'look alive', 'hey']
            night_list = ['good night', 'night', 'i am sleeping', 'sleep', 'go to sleep']
            if str(self.s_process.speak_or_not()).lower().__eq__('awake'):
                command = "termux-dialog speech -t 'Hey, you are talking to Shyna' -i 'Tell me, how can I help?'"
            else:
                command = "termux-dialog speech -t 'Hey, you are talking to Shyna' -i 'I will be quite, I promise.'"
            response = str(self.run_cmd_with_response(command=command)['text']).lower()
            print(response)
            if len(response) > 0:
                if str(response).__contains__('alarm') and str(response).__contains__('set'):
                    self.make_alarm(response)
                elif str(response).__contains__('wake me up at'):
                    self.make_alarm(response)
                elif str(response).__contains__('let me know'):
                    self.make_alarm(response)
                elif str(response) in morning_list:
                    self.s_process.updated_speak_or_not_status(status=True)
                elif str(response) in night_list:
                    self.s_process.updated_speak_or_not_status(status=False)
                else:
                    self.create_notification()
            else:
                command = "Can you please speak little loud or go for the option below"
                self.s_process.shyna_speaks_termux(msg=command)
                self.create_notification()
        except Exception as e:
            command = "termux-toast " + str(e)
            os.popen(cmd=command)
            print(e)
            self.create_notification()

    def create_notification(self):
        try:
            command = str(self.run_cmd_with_response("termux-dialog text -t 'Please enter string having time'")['text'])
            self.make_alarm(call=command)
        except Exception as e:
            print(e)


if __name__ == "__main__":
    ShynaMakeAlarm().initiate_interaction()




import nltk
import os


class ShynaTermuxSetup:
    """We need setup few things to make it work and test"""
    case_env = ''

    def set_env_variable(self):
        try:
            self.case_env = input("Want to add Environment (y/n)")
            if self.case_env.__contains__('yes') or self.case_env.__contains__('y'):
                dbhost = input("Enter the database host")
                dbhost_cmd = "echo 'export host=" + dbhost + "'>>~/.bash_profile;"
                os.popen(dbhost_cmd).readlines()
                dbpasswd = input("Enter the database password")
                dbhost_cmd = "echo 'export passwd=" + dbpasswd + "'>>~/.bash_profile;"
                os.popen(dbhost_cmd).readlines()
                dbhost_cmd = "echo 'export bossname=Shivam'>>~/.bash_profile;"
                os.popen(dbhost_cmd).readlines()
            else:
                pass
            self.case_env = input("Want to install remaining (y/n)")
            if self.case_env.__contains__('yes') or self.case_env.__contains__('y'):
                os.popen("pkg install sox --assume-yes").readline()
                os.popen("pkg install termux-api --assume-yes").readline()
                # os.popen('+')
                dbhost_cmd = """termux-notification --on-delete 'termux-tts-speak "hey Shivam"' -t 'Hey Shivam' """
                os.popen(dbhost_cmd)
                nltk.download('all')
            else:
                pass
        except Exception as e:
            print(e)


if __name__ == '__main__':
    ShynaTermuxSetup().set_env_variable()



from Shynatime import ShTime
from ShynaDatabase import Shdatabase
import os


class ShynaConnection:
    result = ""
    wifi_home_name = 'shivam'
    s_time = ShTime.ClassTime()
    s_data = Shdatabase.ShynaDatabase()
    s_data.device_id = "termux"

    def check_wifi(self):
        self.result = 'phone'
        try:
            wifi_info = os.popen('termux-wifi-connectioninfo').read()
            if str(wifi_info).lower().__contains__(self.wifi_home_name):
                self.result = 'home'
                self.s_data.query = "INSERT INTO connection_check (connection_type, from_application, new_date, new_time)" \
                                    " VALUES ('" + str(self.result) + "','" + str(self.s_data.device_id) + "','" \
                                    + str(self.s_time.now_date) + "','" + str(self.s_time.now_time) + "')"
                self.s_data.create_insert_update_or_delete()
            else:
                self.result = 'phone'
                self.s_data.query = "INSERT INTO connection_check (connection_type, from_application, new_date, new_time)" \
                                    " VALUES ('" + str(self.result) + "','" + str(self.s_data.device_id) + "','" \
                                    + str(self.s_time.now_date) + "','" + str(self.s_time.now_time) + "')"
                self.s_data.create_insert_update_or_delete()
        except Exception as e:
            print(e)
        finally:
            self.s_data.set_date_system(process_name="connection_check")
            return self.result


if __name__ == '__main__':
    ShynaConnection().check_wifi()



from ShynaDatabase import Shdatabase
from ShynaProcess import Shprocess
import os


class ShynaSpeakOnTermux:
    """
    Get sentences from database and speak them as needed
    """
    s_data = Shdatabase.ShynaDatabase()
    s_process = Shprocess.ShynaSpeak()

    def get_sentences(self):
        try:
            pass
        except Exception as e:
            print(e)


if __name__ == '__main__':
    ShynaSpeakOnTermux().get_sentences()



from ShynaDatabase import Shdatabase
from Shynatime import ShTime
from ShynaProcess import Shprocess
import os


class CloseAlarm:
    s_time = ShTime.ClassTime()
    s_data = Shdatabase.ShynaDatabase()
    s_process = Shprocess.ShynaSpeak()

    def close_alarm(self):
        try:
            self.s_data.query = "SELECT count, task_status FROM Task_Manager WHERE task_status = 'running'"
            result = self.s_data.select_from_table()
            print(result, type(result))
            if "Empty" in result:
                print("No")
                os.popen("termux-tts-speak 'Hey, Shiv! You have not set any alarm?!'")
            else:
                for row in result:
                    status = row[1]
                    count = row[0]
                    if str(status).lower().__eq__('running'):
                        print(status)
                        self.s_data.query = "UPDATE Task_Manager SET snooze_duration = '0', task_status='completed' " \
                                            "WHERE count = '" + str(count) + "'"
                        self.s_data.create_insert_update_or_delete()
                        self.s_data.query = "UPDATE Task_Manager SET snooze_duration = '0' WHERE count = '" \
                                            + str(count) + "'"
                        self.s_data.create_insert_update_or_delete()
                        os.popen("termux-tts-speak 'Hi, Closing alarm'")
                        self.s_data.query = "SELECT sunrise from weather_table where task_date = '" \
                                            + str(self.s_time.now_date) + "'"
                        result = self.s_data.select_from_table()
                        if "Empty" in result:
                            pass
                        else:
                            for item in result[0]:
                                if self.s_time.string_to_time(time_string=self.s_time.now_time) <= self.s_time.string_to_time(time_string=item):
                                    self.lights_on()
                                else:
                                    pass
                    else:
                        os.popen("termux-tts-speak 'Hey, Shiv! You have not set any alarm?!'")
        except Exception as e:
            print(e)

    def lights_on(self):
        cmd = "termux-torch on"
        self.s_data.query = "INSERT INTO shyna_termux (task_date, task_time, command_to_run) VALUES ('" \
                            + str(self.s_time.now_date) + "', '" + str(self.s_time.now_time) + "', '" + str(cmd) + "')"
        print(self.s_data.query)
        self.s_data.create_insert_update_or_delete()
        self.s_data.query = "INSERT INTO shyna_rasp (task_date, task_time, command_to_run) VALUES('" \
                            + str(self.s_time.now_date) + "', '" + str(self.s_time.now_time) + "', '" \
                            + str("speak:Good Morning") + "')"
        self.s_data.create_insert_update_or_delete()


if __name__ == '__main__':
    CloseAlarm().close_alarm()



import os
from Shynatime import ShTime
from ShynaDatabase import Shdatabase
import random


class ShynaRun:
    s_data = Shdatabase.ShynaDatabase()
    s_time = ShTime.ClassTime()
    command = ''
    response = None

    def run_cmd_with_response(self, command):
        self.command = command
        try:
            self.response = os.popen(str(self.command)).read()
            self.response = eval(self.response)
        except Exception as e:
            print(e)
            self.response = str(e)
        finally:
            return self.response

    def start_run(self):
        try:
            cmd = "termux-dialog speech"
            call = self.run_cmd_with_response(command=cmd)['text']
            if "" == call:
                sent = ["hello", "Hey", "Yes, tell me", "I am here", "I am busy", "yes, I am here", "hey!",
                        "yep,tell me", "sorry, what?!"]
                choice = "termux-tts-speak -s ALARM '" + random.choice(sent) + "'"
                os.popen(choice)
            else:
                cmd = "termux-toast " + str(call) + ""
                os.popen(cmd)
                self.s_data.query = "INSERT INTO TTM_sent (task_date, task_time, sent) VALUES('" + str(
                    self.s_time.now_date) + "', '" + str(self.s_time.now_time) + "', '" + str(call).lower() + "')"
                insert_status = self.s_data.insert_or_update_or_delete_with_status()
                if insert_status is True:
                    sent = ["Roger that", "Consider it done", "I got your back", "got it", "sure", "okay! processing",
                            "what will you without me?!", "ahan!"]
                    choice = "termux-tts-speak -s ALARM '" + random.choice(sent) + "'"
                    os.popen(choice)
                else:
                    sent = ["something went wrong", "did not worked", "please, try again", "nope, try again",
                            "Exception alert?!", "I ran into error"]
                    choice = "termux-tts-speak -s ALARM '" + random.choice(sent) + "'"
                    os.popen(choice)
        except Exception as e:
            sent = ["something went wrong", "did not worked", "please, try again", "nope, try again",
                    "Exception alert?!", "I ran into error"]
            choice = "termux-tts-speak -s ALARM '" + random.choice(sent) + "'"
            os.popen(choice)
            print(e)


if __name__ == '__main__':
    ShynaRun().start_run()
